@@ -1,9 +1,7 @@
 ## ---- SETTINGS-knitr, include=FALSE--------------------------------------
-stopifnot(require(svglite))
 stopifnot(require(knitr))
 opts_chunk$set(
   comment=NA, message = FALSE, warning = FALSE,
-  dev = 'svglite', fig.ext='svg', fig.path = "SVGs/",
   fig.align='center', fig.width = 7, fig.height = 3
 )
 
@@ -25,13 +23,13 @@ SEED <- 12345
 loo.cores <- if (exists("CORES")) CORES else 1L
 options(loo.cores = loo.cores)
 
-## ----OLS-----------------------------------------------------------------
+## ----lm-clouds-ols-------------------------------------------------------
 data("clouds", package = "HSAUR3")
 ols <- lm(rainfall ~ seeding * (sne + cloudcover + prewetness + echomotion) +
             time, data = clouds)
 round(coef(ols), 3)
 
-## ----MCMC, results='hide'------------------------------------------------
+## ----lm-clouds-mcmc, results='hide'--------------------------------------
 library(rstanarm)
 post <- stan_lm(rainfall ~ seeding * (sne + cloudcover + prewetness + 
                                         echomotion) + time, data = clouds,
@@ -42,7 +40,7 @@ post
 ## ---- echo=FALSE---------------------------------------------------------
 print(post)
 
-## ----ATE, fig.height=3---------------------------------------------------
+## ----lm-clouds-ate-plot, fig.height=3------------------------------------
 clouds_cf <- clouds
 clouds_cf$seeding[] <- "yes"
 y1_rep <- posterior_predict(post, newdata = clouds_cf)
@@ -51,17 +49,17 @@ y0_rep <- posterior_predict(post, newdata = clouds_cf)
 qplot(x = c(y1_rep - y0_rep), geom = "histogram", 
       ylab = NULL, xlab = "Estimated ATE")
 
-## ----SIMPLE, results="hide"----------------------------------------------
+## ----lm-clouds-simple, results="hide"------------------------------------
 simple <- stan_glm(rainfall ~ seeding * (sne + cloudcover + prewetness + 
                                         echomotion) + time,
                    data = clouds, family = gaussian(), 
                    prior = cauchy(), prior_intercept = cauchy(),
                    chains = CHAINS, cores = CORES, seed = SEED)
 
-## ----LOO, warning=TRUE---------------------------------------------------
+## ----lm-clouds-loo, warning=TRUE-----------------------------------------
 (loo_post <- loo(post))
 (loo(simple))
 
-## ----LOO_POST------------------------------------------------------------
+## ----lm-clouds-plot-loo--------------------------------------------------
 plot(loo_post, label_points = TRUE)
 
