@@ -1,5 +1,5 @@
 # Part of the rstanarm package for estimating model parameters
-# Copyright (C) 2015 Trustees of Columbia University
+# Copyright (C) 2015, 2016 Trustees of Columbia University
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -30,9 +30,10 @@ SW <- suppressWarnings
 
 # These tests just make sure that posterior_predict doesn't throw errors and
 # that result has correct dimensions
-check_for_error <- function(fit) {
+check_for_error <- function(fit, data = NULL) {
   nsims <- nrow(as.data.frame(fit))
-  mf <- model.frame(fit)
+  mf <- if (!is.null(data)) 
+    data else model.frame(fit)
   if (identical(deparse(substitute(fit)), "example_model"))
     mf <- lme4::cbpp
   
@@ -59,6 +60,43 @@ check_for_error <- function(fit) {
                regexep = "posterior sample size is only")
 }
 
+
+# Error messages ----------------------------------------------------------
+context("posterior_predict (error messages)")
+test_that("posterior_predict errors if not a stanreg object", {
+  expect_error(posterior_predict(example_model$stanfit), "not a stanreg object")
+  expect_error(posterior_predict(summary(example_model)), "not a stanreg object")
+})
+test_that("posterior_predict errors if model fit using optimization", {
+  fit1 <- stan_glm(mpg ~ wt + cyl + am, data = mtcars, algorithm = "optimizing", 
+                   seed = SEED)
+  expect_error(posterior_predict(fit1), regexp = "optimizing")
+})
+test_that("posterior_predict errors if NAs in newdata", {
+  nd <- model.frame(example_model)
+  nd$period[1] <- NA
+  expect_error(posterior_predict(example_model, newdata = nd), 
+               regexp = "NAs are not allowed in 'newdata'")
+})
+test_that("posterior_predict errors if draws > posterior sample size", {
+  expect_error(posterior_predict(example_model, draws = 1e6), 
+               regexp = "'draws' should be <= posterior sample size")
+})
+
+
+# VB ----------------------------------------------------------------------
+context("posterior_predict ok for vb")
+test_that("errors for optimizing and silent for vb", {
+  fit1 <- stan_glm(mpg ~ wt + cyl + am, data = mtcars, algorithm = "meanfield", 
+                   seed = SEED)
+  fit2 <- update(fit1, algorithm = "fullrank")
+  expect_silent(posterior_predict(fit1))
+  expect_silent(posterior_predict(fit2))
+})
+
+
+
+# MCMC --------------------------------------------------------------------
 context("posterior_predict (stan_lm)")
 test_that("posterior_predict compatible with stan_lm", {
   fit <- SW(stan_lm(mpg ~ wt + cyl + am, data = mtcars, prior = R2(log(0.5), what = "log"),
@@ -71,8 +109,17 @@ test_that("compatible with gaussian glm", {
   fit <- SW(stan_glm(mpg ~ wt, data = mtcars, 
                      iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH))
   check_for_error(fit)
-  fit_off <- SW(update(fit, offset = runif(nrow(mtcars))))
-  check_for_error(fit)
+})
+test_that("compatible with glm with offset", {
+  mtcars2 <- mtcars
+  mtcars2$offs <- runif(nrow(mtcars))
+  fit <- SW(stan_glm(mpg ~ wt, data = mtcars2, offset = offs,
+                     iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH))
+  fit2 <- SW(stan_glm(mpg ~ wt + offset(offs), data = mtcars2,
+                      iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH))
+  
+  check_for_error(fit, data = mtcars2)
+  check_for_error(fit2, data = mtcars2)
 })
 test_that("compatible with poisson & negbin glm", {
   counts <- c(18,17,15,20,10,20,25,13,12)
@@ -102,8 +149,32 @@ test_that("compatible with stan_polr", {
   fit <- SW(stan_polr(tobgp ~ agegp + alcgp, data = esoph, prior = R2(location = 0.4),
                    iter = ITER, chains = CHAINS, seed = SEED, refresh = REFRESH))
   check_for_error(fit)
+  
+  esoph$tobgp_fac <- factor(esoph$tobgp == "30+")
+  fit_2level <- SW(stan_polr(tobgp_fac ~ agegp + alcgp, 
+                             data = esoph, prior = R2(location = 0.4), 
+                             chains = CHAINS, iter = ITER, 
+                             seed = SEED, refresh = REFRESH))
+  check_for_error(fit_2level)
+  
+  fit_2level_scobit <- SW(update(fit_2level, shape = 2, rate = 2))
+  check_for_error(fit_2level_scobit)
 })
 
+context("posterior_predict (stan_gamm4)")
+test_that("stan_gamm4 returns expected result for sleepstudy example", {
+  fit <- SW(stan_gamm4(Reaction / 10 ~ s(Days), data = sleepstudy,
+                       random = ~(1|Subject), chains = CHAINS, iter = ITER, 
+                       seed = SEED, refresh = REFRESH))
+  expect_silent(yrep1 <- posterior_predict(fit))
+  # expect_equal(dim(yrep1), c(nrow(as.data.frame(fit)), nobs(fit)))
+  expect_silent(yrep2 <- posterior_predict(fit, draws = 1))
+  # expect_equal(dim(yrep2), c(1, nobs(fit)))
+  expect_error(posterior_predict(fit, newdata = model.frame(fit$gam)), 
+               "not yet supported for models estimated via 'stan_gamm4'")
+})
+
+
 context("posterior_predict (stan_(g)lmer)")
 test_that("compatible with stan_lmer", {
   fit <- SW(stan_lmer(mpg ~ wt + (1|cyl) + (1 + wt|gear), data = mtcars, 
@@ -130,18 +201,7 @@ test_that("compatible with stan_(g)lmer with transformation in formula", {
 })
 
 
-context("posterior_predict (optimizing and vb)")
-test_that("errors for optimizing and silent for vb", {
-  fit1 <- stan_glm(mpg ~ wt + cyl + am, data = mtcars, algorithm = "optimizing", 
-                   seed = SEED)
-  fit2 <- update(fit1, algorithm = "meanfield")
-  fit3 <- update(fit1, algorithm = "fullrank")
-  expect_error(posterior_predict(fit1), regexp = "optimizing")
-  expect_silent(posterior_predict(fit2))
-  expect_silent(posterior_predict(fit3))
-})
-
-
+# compare to lme4 ---------------------------------------------------------
 context("posterior_predict (compare to lme4)")
 test_that("posterior_predict close to predict.merMod for gaussian", {
   mod1 <- as.formula(mpg ~ wt + (1|cyl) + (1|gear))
@@ -208,7 +268,7 @@ test_that("posterior_predict close to predict.merMod for binomial", {
                              seed = SEED)
   spred <- sweep(spred, 2, rowSums(get_y(sfit)), "/")
   expect_equal(colMeans(spred), unname(colMeans(lpred)),
-               tol = .1)
+               tol = .125)
 })
 
 test_that("edge cases for posterior_predict work correctly", {
@@ -269,3 +329,20 @@ test_that("lme4 tests work similarly", {
   p5 <- posterior_predict(sfit, nd, re.form=~(1|plate), seed = SEED)
 })
 
+
+# helper functions --------------------------------------------------------
+context("posterior_predict helper functions")
+test_that("pp_binomial_trials works", {
+  ppbt <- rstanarm:::pp_binomial_trials
+  
+  # binomial
+  expect_equal(ppbt(example_model), cbpp$size)
+  expect_equal(ppbt(example_model, newdata = cbpp[1:5, ]), cbpp[1:5, "size"])
+  
+  # bernoulli
+  fit <- SW(stan_glm(I(mpg > 25) ~ wt, data = mtcars, family = binomial, 
+                     iter = ITER, refresh = REFRESH, chains = CHAINS, 
+                     seed = SEED))
+  expect_equal(ppbt(fit), rep(1, nrow(mtcars)))
+  expect_equal(ppbt(fit, newdata = mtcars[1:5, ]), rep(1, 5))
+})
