@@ -1,5 +1,5 @@
 # Part of the rstanarm package for estimating model parameters
-# Copyright (C) 2015 Trustees of Columbia University
+# Copyright (C) 2015, 2016 Trustees of Columbia University
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,15 +23,16 @@ SEED <- 123
 ITER <- 100
 CHAINS <- 2
 CORES <- 1
-REFRESH <- ITER
+REFRESH <- 0
 
 threshold <- 0.03
 
 context("stan_polr")
+
 test_that("stan_polr runs for esoph example", {
   library(MASS)
   f <- tobgp ~ agegp + alcgp
-  fit1 <- stan_polr(f, data = esoph, method = "loglog",
+  fit1 <- stan_polr(f, data = esoph, method = "loglog", prior_PD = TRUE,
                     prior = R2(location = 0.4, what = "median"),
                     chains = CHAINS, iter = ITER, seed = SEED, refresh = REFRESH)
   fit1vb <- stan_polr(f, data = esoph, method = "loglog",
@@ -48,12 +49,14 @@ test_that("stan_polr runs for esoph example", {
   expect_is(fit2, "stanreg")
   expect_is(fit1vb, "stanreg")
   expect_is(fit2vb, "stanreg")
-  
-  
-  # fit <- stan_polr(f, data = esoph, prior = NULL, 
-  #                  algorithm = "fullrank", seed = SEED)
-  # check <- polr(f, data = esoph)
-  # expect_equal(coef(fit), coef(check), threshold)
+})
+
+test_that("stan_polr throws error if formula excludes intercept", {
+  expect_error(stan_polr(tobgp ~ 0 + agegp + alcgp, data = esoph, 
+                         method = "loglog", prior = R2(0.4, "median"),
+                         chains = CHAINS, iter = ITER, seed = SEED, 
+                         refresh = REFRESH), 
+               regexp = "not allowed")
 })
 
 test_that("gumbel functions ok", {
